@@ -5,34 +5,12 @@
  *
  * Header file for doubly linked lists in the libmgec shared library.
  *
- * @author Copyright (C) 2016-2019, 2021, 2022  Mark Grant
+ * @author Copyright (C) 2016-2019, 2021-2023  Mark Grant
  *
  * Released under the GPLv3 only.\n
  * SPDX-License-Identifier: GPL-3.0-only
  *
- * @version _v1.0.9 ==== 16/09/2022_
- */
-
-/* **********************************************************************
- *									*
- * Changelog								*
- *									*
- * Date		Author	Version	Description				*
- *									*
- * 06/05/2016	MG	1.0.1	First release.				*
- * 16/07/2016	MG	1.0.2	Move towards kernel coding style.	*
- * 17/07/2016	MG	1.0.3	Remove function prototype comments.	*
- * 05/11/2017	MG	1.0.4	Add Doxygen comments.			*
- * 09/11/2017	MG	1.0.5	Add SPDX license tag.			*
- * 02/01/2018	MG	1.0.6	Move to new source directory structure.	*
- * 11/06/2019	MG	1.0.7	clang-format coding style changes.	*
- *				Extract find_prev and find_next from .c	*
- *				file and make static inline.		*
- * 03/12/2021	MG	1.0.8	Tighten SPDX tag.			*
- * 16/09/2022	MG	1.0.9	Rename of portability.h			*
- *				Add stddef.h for size_t.		*
- *									*
- ************************************************************************
+ * @version _v1.1.0 ==== 02/11/2023_
  */
 
 #ifndef DLLIST_H
