@@ -1,7 +1,6 @@
 /* **********************************************************************
  *									*
- * Source: main.c							*
- * Author Copyright (C) 2017-2019, 2021, 2022  Mark Grant		*
+ * Author Copyright (C) 2017-2019, 2021-2023  Mark Grant		*
  *									*
  * Purpose:								*
  *	Test program for binary search trees in libmgec shared library.	*
@@ -32,7 +31,7 @@ static int verbose;
 int nodecmp(const struct testnode *node1, const struct testnode *node2);
 struct bstree *pop_tree(struct bstree *tree, int duplicates);
 char *printtree(struct bstree *root, char *output);
-int cmpresfile(char *result, char *answer);
+int cmpresfile(const char *result, const char *answer);
 int test_tree_pop(void);
 int testfind_bst_node(void);
 int testget_counter_bst_node(void);
@@ -270,9 +269,9 @@ int nodecmp(const struct testnode *node1, const struct testnode *node2)
  */
 struct bstree *pop_tree(struct bstree *tree, int duplicates)
 {
-	char *str[] = { "consistency", "is",   "all",  "i",   "ask",
-			"give",	       "us",   "this", "day", "our",
-			"daily",       "mask", "\0" };
+	const char *str[] = { "consistency", "is",   "all",  "i",   "ask",
+			      "give",	     "us",   "this", "day", "our",
+			      "daily",	     "mask", "\0" };
 	struct testnode test;
 	struct bstree *res;
 	int i;
@@ -350,7 +349,7 @@ char *printtree(struct bstree *tree, char *output)
 /*
  * Compare the test result file to the pre-determined test answer file.
  */
-int cmpresfile(char *result, char *answer)
+int cmpresfile(const char *result, const char *answer)
 {
 	FILE *fp, *fp1;
 	int status = 0;
@@ -477,8 +476,8 @@ int testfind_bst_node(void)
 			 node2.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Find %s found %s with mge_errno %d\n", node2.key,
-			 pnode->key, mge_errno);
+			 "Find %s found NULL with mge_errno %d\n", node2.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -501,8 +500,8 @@ int testfind_bst_node(void)
 			 node3.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Find %s found %s with mge_errno %d\n", node3.key,
-			 pnode->key, mge_errno);
+			 "Find %s found NULL with mge_errno %d\n", node3.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -525,8 +524,8 @@ int testfind_bst_node(void)
 			 node4.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Find %s found %s with mge_errno %d\n", node4.key,
-			 pnode->key, mge_errno);
+			 "Find %s found NULL with mge_errno %d\n", node4.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -549,8 +548,8 @@ int testfind_bst_node(void)
 			 node5.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Find %s found %s with mge_errno %d\n", node5.key,
-			 pnode->key, mge_errno);
+			 "Find %s found NULL with mge_errno %d\n", node5.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -573,8 +572,8 @@ int testfind_bst_node(void)
 			 node6.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Find %s found %s with mge_errno %d\n", node6.key,
-			 pnode->key, mge_errno);
+			 "Find %s found NULL with mge_errno %d\n", node6.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -597,8 +596,8 @@ int testfind_bst_node(void)
 			 node7.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Find %s found %s with mge_errno %d\n", node7.key,
-			 pnode->key, mge_errno);
+			 "Find %s found NULL with mge_errno %d\n", node7.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -806,8 +805,8 @@ int testfind_next_bst_node(void)
 			 node2.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Next found after %s is %s & mge_errno %d\n",
-			 node2.key, pnode->key, mge_errno);
+			 "Next found after %s is NULL & mge_errno %d\n",
+			 node2.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -830,8 +829,8 @@ int testfind_next_bst_node(void)
 			 node3.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Next found after %s is %s & mge_errno %d\n",
-			 node3.key, pnode->key, mge_errno);
+			 "Next found after %s is NULL & mge_errno %d\n",
+			 node3.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -854,8 +853,8 @@ int testfind_next_bst_node(void)
 			 node4.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Next found after %s is %s & mge_errno %d\n",
-			 node4.key, pnode->key, mge_errno);
+			 "Next found after %s is NULL & mge_errno %d\n",
+			 node4.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -878,8 +877,8 @@ int testfind_next_bst_node(void)
 			 node5.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Next found after %s is %s & mge_errno %d\n",
-			 node5.key, pnode->key, mge_errno);
+			 "Next found after %s is NULL & mge_errno %d\n",
+			 node5.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -902,8 +901,8 @@ int testfind_next_bst_node(void)
 			 node6.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Next found after %s is %s & mge_errno %d\n",
-			 node6.key, pnode->key, mge_errno);
+			 "Next found after %s is NULL & mge_errno %d\n",
+			 node6.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -926,8 +925,8 @@ int testfind_next_bst_node(void)
 			 node7.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Next found after %s is %s & mge_errno %d\n",
-			 node7.key, pnode->key, mge_errno);
+			 "Next found after %s is NULL & mge_errno %d\n",
+			 node7.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -995,9 +994,9 @@ int testfind_prev_bst_node(void)
 			 node2.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Previous found before %s is %s with "
+			 "Previous found before %s is NULL with "
 			 "mge_errno %d\n",
-			 node2.key, pnode->key, mge_errno);
+			 node2.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1020,9 +1019,9 @@ int testfind_prev_bst_node(void)
 			 node3.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Previous found before %s is %s with "
+			 "Previous found before %s is NULL with "
 			 "mge_errno %d\n",
-			 node3.key, pnode->key, mge_errno);
+			 node3.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1045,9 +1044,9 @@ int testfind_prev_bst_node(void)
 			 node4.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Previous found before %s is %s with "
+			 "Previous found before %s is NULL with "
 			 "mge_errno %d\n",
-			 node4.key, pnode->key, mge_errno);
+			 node4.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1070,9 +1069,9 @@ int testfind_prev_bst_node(void)
 			 node5.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Previous found before %s is %s with "
+			 "Previous found before %s is NULL with "
 			 "mge_errno %d\n",
-			 node5.key, pnode->key, mge_errno);
+			 node5.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1095,9 +1094,9 @@ int testfind_prev_bst_node(void)
 			 node6.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Previous found before %s is %s with "
+			 "Previous found before %s is NULL with "
 			 "mge_errno %d\n",
-			 node6.key, pnode->key, mge_errno);
+			 node6.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1120,9 +1119,9 @@ int testfind_prev_bst_node(void)
 			 node7.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Previous found before %s is %s with "
+			 "Previous found before %s is NULL with "
 			 "mge_errno %d\n",
-			 node7.key, pnode->key, mge_errno);
+			 node7.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1145,9 +1144,9 @@ int testfind_prev_bst_node(void)
 			 node8.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Previous found before %s is %s with "
+			 "Previous found before %s is NULL with "
 			 "mge_errno %d\n",
-			 node8.key, pnode->key, mge_errno);
+			 node8.key, mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1208,8 +1207,8 @@ int testupd_bst_node(void)
 			 node.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Find %s found %s with mge_errno %d\n", node.key,
-			 pnode->key, mge_errno);
+			 "Find %s found NULL with mge_errno %d\n", node.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1231,8 +1230,8 @@ int testupd_bst_node(void)
 			 node.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Update %s found %s with mge_errno %d\n", node.key,
-			 pnode->key, mge_errno);
+			 "Update %s found NULL with mge_errno %d\n", node.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1254,8 +1253,8 @@ int testupd_bst_node(void)
 			 node.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Find %s found %s with mge_errno %d\n", node.key,
-			 pnode->key, mge_errno);
+			 "Find %s found NULL with mge_errno %d\n", node.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1277,8 +1276,8 @@ int testupd_bst_node(void)
 			 node.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Update %s found %s with mge_errno %d\n", node.key,
-			 pnode->key, mge_errno);
+			 "Update %s found NULL with mge_errno %d\n", node.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1300,8 +1299,8 @@ int testupd_bst_node(void)
 			 node.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Find %s found %s with mge_errno %d\n", node.key,
-			 pnode->key, mge_errno);
+			 "Find %s found NULL with mge_errno %d\n", node.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1323,8 +1322,8 @@ int testupd_bst_node(void)
 			 node.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Update %s found %s with mge_errno %d\n", node.key,
-			 pnode->key, mge_errno);
+			 "Update %s found NULL with mge_errno %d\n", node.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1346,8 +1345,8 @@ int testupd_bst_node(void)
 			 node.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Find %s found %s with mge_errno %d\n", node.key,
-			 pnode->key, mge_errno);
+			 "Find %s found NULL with mge_errno %d\n", node.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
@@ -1369,8 +1368,8 @@ int testupd_bst_node(void)
 			 node.key, pnode->key, pnode->payload, mge_errno);
 	else
 		snprintf(presult, ARRAY_SIZE(result),
-			 "Update %s found %s with mge_errno %d\n", node.key,
-			 pnode->key, mge_errno);
+			 "Update %s found NULL with mge_errno %d\n", node.key,
+			 mge_errno);
 	fputs(result, fp);
 
 	if (verbose)
